
% Code to make figures 5a)-d), Different gaits
% Argument of the function: 
% n_gait: 0 =  trot, 1 = pace, 2 = bound, 3 = walk

function[gait] = cpgs_gaits(n_gait)

gait=zeros(4,4);

epsilon = 0.5; %dephasage between the hind limbs for bound

if(n_gait==1)
    gait= [0 pi pi 0; pi 0 0 pi; pi 0 0 pi; 0 pi pi 0];
    Name='Trot';
end
if(n_gait==2)
    gait= [0 pi 0 pi; -pi 0 -pi 0; 0 pi 0 pi; -pi 0 -pi 0];
    Name='Pace';
end
if(n_gait==3)
    
    gait=  [0 0 pi-epsilon pi+epsilon; 
            0 0 pi-epsilon pi+epsilon; 
            -pi+epsilon -pi+epsilon 0 2*epsilon; 
            -pi-epsilon -pi-epsilon -2*epsilon 0];
    Name='Bound';
end
if(n_gait==4)
    gait= [0 pi -pi/2 pi/2; -pi 0 pi/2 pi/2; pi/2 -pi/2 0 pi; -pi/2 -pi/2 -pi 0];
    Name='Walk';
end

theta=zeros(1,4,4);


%integration
dt   = 0.001;
T(1) = 0;
time = 2000;

% CONTROL PARAMETERS

for i = [1:time]
    
    mu(i)=1;
    omega(i)=2*pi;
    mu2(i)=1;
    omega2(i)=2*pi;
    mu3(i)=1;
    omega3(i)=4*pi;
    mu4(i)=1;
    omega4(i)=4*pi;
    gamma(i)=0;
    gamma2(i)=0;
    gamma3(i)=0;
    gamma4(i)=0;
    
    theta(i,:,:)=gait;
    
end


%PARAMETERS
b = 5;
a= 5;
c = 20;
kx=8;
ky=8;

%VARIABLES INITIAL CONDITIONS

h_d(1)=0;
x_d(1)=0;
y_d(1)=0;

h_d2(1)=0;
x_d2(1)=0;
y_d2(1)=0;

h_d3(1)=0;
x_d3(1)=0;
y_d3(1)=0;

h_d4(1)=0;
x_d4(1)=0;
y_d4(1)=0;

x_h(1)=0;
v_h(1)=-1;
m(i)=0;

x_h2(1)=0;
v_h2(1)=-1;
m2(i)=0;

x_h3(1)=0;
v_h3(1)=-1;
m3(i)=0;

x_h4(1)=0;
v_h4(1)=-1;
m4(i)=0;




for i = [1:time]

    
  if(i>2)
     if(gamma(i)>(gamma(i-1)+0.1) || gamma(i)<(gamma(i-1)-0.1))
             h_d(i)=0;
     end
     if(gamma2(i)>(gamma2(i-1)+0.1) || gamma2(i)<(gamma2(i-1)-0.1))
             h_d2(i)=0;
     end
     if(gamma3(i)>(gamma3(i-1)+0.1) || gamma3(i)<(gamma3(i-1)-0.1))
             h_d3(i)=0;
     end
  end
       

    %DISCRETE SYSTEM
    dh_d(i) = 1-h_d(i);
    dx_d(i) = y_d(i);
    dy_d(i) = h_d(i)*b * (h_d(i)*b/4 *(gamma(i)-x_d(i)) - y_d(i));
    
    dh_d2(i) = 1-h_d2(i);
    dx_d2(i) = y_d2(i);
    dy_d2(i) = h_d2(i)*b * (h_d2(i)*b/4 *(gamma2(i)-x_d2(i)) - y_d2(i));
    
    dh_d3(i) = 1-h_d3(i);
    dx_d3(i) = y_d3(i);
    dy_d3(i) = h_d3(i)*b * (h_d3(i)*b/4 *(gamma3(i)-x_d3(i)) - y_d3(i));
    
    dh_d4(i) = 1-h_d4(i);
    dx_d4(i) = y_d4(i);
    dy_d4(i) = h_d4(i)*b * (h_d4(i)*b/4 *(gamma4(i)-x_d4(i)) - y_d4(i));
    
    %RHYTHMIC SYSTEM
    dm(i)=c*(mu(i)-m(i));
    dm2(i)=c*(mu2(i)-m2(i));      
    dm3(i)=c*(mu3(i)-m3(i));
    dm4(i)=c*(mu4(i)-m4(i));
    
    r_h = sqrt((x_h(i)-x_d(i))^2 + v_h(i)^2);
    dx_h(i) = a/abs(mu(i))  * (m(i)-r_h^2) * (x_h(i)-x_d(i)) - omega(i) * v_h(i)+randn;
    dv_h(i) = a/abs(mu(i))  * (m(i)-r_h^2) * v_h(i) + omega(i)* (x_h(i)-x_d(i))+randn;
      
    r_h2 = sqrt((x_h2(i)-x_d2(i))^2 + v_h2(i)^2);
    dx_h2(i) = a/abs(mu2(i))  * (m2(i)-r_h2^2) * (x_h2(i)-x_d2(i)) - omega2(i) * v_h2(i)+randn;
    dv_h2(i) = a/abs(mu2(i))  * (m2(i)-r_h2^2) * v_h2(i) + omega2(i)* (x_h2(i)-x_d2(i))+randn ;

    r_h3 = sqrt((x_h3(i)-x_d3(i))^2 + v_h3(i)^2);
    dx_h3(i) = a/abs(mu3(i))  * (m3(i)-r_h3^2) * (x_h3(i)-x_d3(i)) - omega3(i) * v_h3(i)+randn;
    dv_h3(i) = a/abs(mu3(i))  * (m3(i)-r_h3^2) * v_h3(i) + omega3(i)* (x_h3(i)-x_d3(i))+randn;
    
    r_h4 = sqrt((x_h4(i)-x_d4(i))^2 + v_h4(i)^2);
    dx_h4(i) = a/abs(mu4(i))  * (m4(i)-r_h4^2) * (x_h4(i)-x_d4(i)) - omega4(i) * v_h4(i)+randn;
    dv_h4(i) = a/abs(mu4(i))  * (m4(i)-r_h4^2) * v_h4(i) + omega4(i)* (x_h4(i)-x_d4(i))+randn;
    
    
    %**********coupling**************
    
  dx_h(i)=dx_h(i)+kx*(cos(theta(i,1,2))*(x_h2(i)-x_d2(i))-sin(theta(i,1,2))*v_h2(i));
  dv_h(i)=dv_h(i)+ky*(sin(theta(i,1,2))*(x_h2(i)-x_d2(i))+cos(theta(i,1,2))*v_h2(i));
    
    dx_h(i)=dx_h(i)+kx*(cos(theta(i,1,3))*(x_h3(i)-x_d3(i))-sin(theta(i,1,3))*v_h3(i));
    dv_h(i)=dv_h(i)+ky*(sin(theta(i,1,3))*(x_h3(i)-x_d3(i))+cos(theta(i,1,3))*v_h3(i));
    
    dx_h(i)=dx_h(i)+kx*(cos(theta(i,1,4))*(x_h4(i)-x_d4(i))-sin(theta(i,1,4))*v_h4(i));
    dv_h(i)=dv_h(i)+ky*(sin(theta(i,1,4))*(x_h4(i)-x_d4(i))+cos(theta(i,1,4))*v_h4(i));
    
    
   dx_h2(i)=dx_h2(i)+kx*(cos(theta(i,2,1))*(x_h(i)-x_d(i))-sin(theta(i,2,1))*v_h(i));
   dv_h2(i)=dv_h2(i)+ky*(sin(theta(i,2,1))*(x_h(i)-x_d(i))+cos(theta(i,2,1))*v_h(i));
    
    dx_h2(i)=dx_h2(i)+kx*(cos(theta(i,2,3))*(x_h3(i)-x_d3(i))-sin(theta(i,2,3))*v_h3(i));
    dv_h2(i)=dv_h2(i)+ky*(sin(theta(i,2,3))*(x_h3(i)-x_d3(i))+cos(theta(i,2,3))*v_h3(i));
    
    dx_h2(i)=dx_h2(i)+kx*(cos(theta(i,2,4))*(x_h4(i)-x_d4(i))-sin(theta(i,2,4))*v_h4(i));
    dv_h2(i)=dv_h2(i)+ky*(sin(theta(i,2,4))*(x_h4(i)-x_d4(i))+cos(theta(i,2,4))*v_h4(i));
    
    
    dx_h3(i)=dx_h3(i)+kx*(cos(theta(i,3,2))*(x_h2(i)-x_d2(i))-sin(theta(i,3,2))*v_h2(i));
    dv_h3(i)=dv_h3(i)+ky*(sin(theta(i,3,2))*(x_h2(i)-x_d2(i))+cos(theta(i,3,2))*v_h2(i));
    
    dx_h3(i)=dx_h3(i)+kx*(cos(theta(i,3,1))*(x_h(i)-x_d(i))-sin(theta(i,3,1))*v_h(i));
    dv_h3(i)=dv_h3(i)+ky*(sin(theta(i,3,1))*(x_h(i)-x_d(i))+cos(theta(i,3,1))*v_h(i));
    
    dx_h3(i)=dx_h3(i)+kx*(cos(theta(i,3,4))*(x_h4(i)-x_d4(i))-sin(theta(i,3,4))*v_h4(i));
    dv_h3(i)=dv_h3(i)+ky*(sin(theta(i,3,4))*(x_h4(i)-x_d4(i))+cos(theta(i,3,4))*v_h4(i));
    
    
    dx_h4(i)=dx_h4(i)+kx*(cos(theta(i,4,2))*(x_h2(i)-x_d2(i))-sin(theta(i,4,2))*v_h2(i));
    dv_h4(i)=dv_h4(i)+ky*(sin(theta(i,4,2))*(x_h2(i)-x_d2(i))+cos(theta(i,4,2))*v_h2(i));
    
    dx_h4(i)=dx_h4(i)+kx*(cos(theta(i,4,3))*(x_h3(i)-x_d3(i))-sin(theta(i,4,3))*v_h3(i));
    dv_h4(i)=dv_h4(i)+ky*(sin(theta(i,4,3))*(x_h3(i)-x_d3(i))+cos(theta(i,4,3))*v_h3(i));
    
    dx_h4(i)=dx_h4(i)+kx*(cos(theta(i,4,1))*(x_h(i)-x_d(i))-sin(theta(i,4,1))*v_h(i));
    dv_h4(i)=dv_h4(i)+ky*(sin(theta(i,4,1))*(x_h(i)-x_d(i))+cos(theta(i,4,1))*v_h(i));


    %*******EULER**************

    T(i+1)=T(i)+dt;

    %discrete
    h_d(i+1)=h_d(i)+dh_d(i)*dt;
    y_d(i+1)=y_d(i)+dy_d(i)*dt;
    x_d(i+1)=x_d(i)+dx_d(i)*dt;
    
    h_d3(i+1)=h_d3(i)+dh_d3(i)*dt;
    y_d3(i+1)=y_d3(i)+dy_d3(i)*dt;
    x_d3(i+1)=x_d3(i)+dx_d3(i)*dt;
    
    h_d2(i+1)=h_d2(i)+dh_d2(i)*dt;
    y_d2(i+1)=y_d2(i)+dy_d2(i)*dt;
    x_d2(i+1)=x_d2(i)+dx_d2(i)*dt;
    
    h_d4(i+1)=h_d4(i)+dh_d4(i)*dt;
    y_d4(i+1)=y_d4(i)+dy_d4(i)*dt;
    x_d4(i+1)=x_d4(i)+dx_d4(i)*dt;
    
    
    x_h(i+1)=x_h(i)+dx_h(i)*dt;
    v_h(i+1)=v_h(i)+dv_h(i)*dt;
    
    x_h2(i+1)=x_h2(i)+dx_h2(i)*dt;
    v_h2(i+1)=v_h2(i)+dv_h2(i)*dt;
    
    x_h3(i+1)=x_h3(i)+dx_h3(i)*dt;
    v_h3(i+1)=v_h3(i)+dv_h3(i)*dt;
    
        
    x_h4(i+1)=x_h4(i)+dx_h4(i)*dt;
    v_h4(i+1)=v_h4(i)+dv_h4(i)*dt;

    m(i+1) = m(i) + dm(i)*dt;
    m2(i+1) = m2(i) + dm2(i)*dt;
    m3(i+1) = m3(i) + dm3(i)*dt;
    
end

figure

plot(T, x_h+24,'red--',T, x_h2+16,'green',T, x_h3+8,'blue:',T, x_h4, 'magenta-.','LineWidth',4)
xlabel('Time [s]', 'FontSize', 20);

set(gca,'YTick',[0 8 16 24]);
set(gca,'YTickLabel',{'RH','LH','RF','LF'},'FontSize',16);
set(gca, 'XLim', [0 time*dt], 'FontSize',20);
set(gca, 'YLim', [-5.5 29.5], 'FontSize',20);
set(gca, 'XTickLabel', []);
















    
