% Code to make figure 15: modulation of stance duration 

clear all; 

%integration
dt   = 0.001;
T(1) = 0;

%CONTROL PARAMETERS

OMEGA = 2*pi;

for i = [1:(2/dt)]
    
    mu(i)=1;
    om_st(i)=4*pi;
    om_sw(i)=OMEGA*om_st(i)/(om_st(i)-OMEGA);
    mu2(i)=1;
    om_st2(i)=2.5*pi;
    om_sw2(i)=OMEGA*om_st2(i)/(om_st2(i)-OMEGA);
    mu3(i)=1;
    om_st3(i)=10*pi;
    om_sw3(i)=OMEGA*om_st3(i)/(om_st3(i)-OMEGA);
    gamma(i)=0;
    gamma2(i)=0;
    gamma3(i)=0;
        
end




%PARAMETERS
b = 10;
f=100;
a= 2;
c = 20;

%VARIABLES INITIAL CONDITIONS

h_d(1)=0;
x_d(1)=0;
y_d(1)=0;

h_d2(1)=0;
x_d2(1)=0;
y_d2(1)=0;

h_d3(1)=0;
x_d3(1)=0;
y_d3(1)=0;

x_h(1)=0;
v_h(1)=-1;

x_h2(1)=0;
v_h2(1)=-1;

x_h3(1)=0;
v_h3(1)=-1;

m(1)=0;
m2(1)=0;
m3(1)=0;

for i = [1:(2/dt)]

    omega(i)= om_sw(i)/(exp(-f*v_h(i))+1)+ om_st(i)/(exp(f*v_h(i))+1);
    omega2(i)= om_sw2(i)/(exp(-f*v_h2(i))+1)+ om_st2(i)/(exp(f*v_h2(i))+1);
    omega3(i)= om_sw3(i)/(exp(-f*v_h3(i))+1)+ om_st3(i)/(exp(f*v_h3(i))+1);
       

    %DISCRETE SYSTEM
    dh_d(i) = 1-h_d(i);
    dx_d(i) = y_d(i);
    dy_d(i) = h_d(i)*b * (h_d(i)*b/4 *(gamma(i)-x_d(i)) - y_d(i));
    
    dh_d2(i) = 1-h_d2(i);
    dx_d2(i) = y_d2(i);
    dy_d2(i) = h_d2(i)*b * (h_d2(i)*b/4 *(gamma2(i)-x_d2(i)) - y_d2(i));
    
    dh_d3(i) = 1-h_d3(i);
    dx_d3(i) = y_d3(i);
    dy_d3(i) = h_d3(i)*b * (h_d3(i)*b/4 *(gamma3(i)-x_d3(i)) - y_d3(i));
    
    %RHYTHMIC SYSTEM 
    dm(i)=c*(mu(i)-m(i));
    dm2(i)=c*(mu2(i)-m2(i));      
    dm3(i)=c*(mu3(i)-m3(i));
    
    r_h = sqrt((x_h(i)-x_d(i))^2 + v_h(i)^2);
    dx_h(i) = a/abs(mu(i)) * (m(i)-r_h^2) * (x_h(i)-x_d(i)) - omega(i) * v_h(i)+randn;
    dv_h(i) = a/abs(mu(i)) * (m(i)-r_h^2) * v_h(i) + omega(i)* (x_h(i)-x_d(i))+randn;
    
    r_h2 = sqrt((x_h2(i)-x_d2(i))^2 + v_h2(i)^2);
    dx_h2(i) = a/abs(mu2(i)) * (m2(i)-r_h2^2) * (x_h2(i)-x_d2(i)) - omega2(i) * v_h2(i)+randn;
    dv_h2(i) = a/abs(mu2(i)) * (m2(i)-r_h2^2) * v_h2(i) + omega2(i)* (x_h2(i)-x_d2(i))+randn ;

    r_h3 = sqrt((x_h3(i)-x_d3(i))^2 + v_h3(i)^2);
    dx_h3(i) = a/abs(mu3(i)) * (m3(i)-r_h3^2) * (x_h3(i)-x_d3(i)) - omega3(i) * v_h3(i)+randn;
    dv_h3(i) = a/abs(mu3(i)) * (m3(i)-r_h3^2) * v_h3(i) + omega3(i)* (x_h3(i)-x_d3(i))+randn;


    %*******EULER**************

    T(i+1)=T(i)+dt;

    %discrete
    h_d(i+1)=h_d(i)+dh_d(i)*dt;
    y_d(i+1)=y_d(i)+dy_d(i)*dt;
    x_d(i+1)=x_d(i)+dx_d(i)*dt;
    
    h_d3(i+1)=h_d3(i)+dh_d3(i)*dt;
    y_d3(i+1)=y_d3(i)+dy_d3(i)*dt;
    x_d3(i+1)=x_d3(i)+dx_d3(i)*dt;
    
    h_d2(i+1)=h_d2(i)+dh_d2(i)*dt;
    y_d2(i+1)=y_d2(i)+dy_d2(i)*dt;
    x_d2(i+1)=x_d2(i)+dx_d2(i)*dt;
    
    
    x_h(i+1)=x_h(i)+dx_h(i)*dt;
    v_h(i+1)=v_h(i)+dv_h(i)*dt;
    
    x_h2(i+1)=x_h2(i)+dx_h2(i)*dt;
    v_h2(i+1)=v_h2(i)+dv_h2(i)*dt;
    
    x_h3(i+1)=x_h3(i)+dx_h3(i)*dt;
    v_h3(i+1)=v_h3(i)+dv_h3(i)*dt;
    
    m(i+1) = m(i) + dm(i)*dt;
    m2(i+1) = m2(i) + dm2(i)*dt;
    m3(i+1) = m3(i) + dm3(i)*dt;

end

figure;

subplot(3,1,1)
plot(T, x_h,'red--','LineWidth',4)


subplot(3,1,2)
plot(T, x_h2,'blue-.','LineWidth',4)

subplot(3,1,3)
plot(T, x_h3,'black','LineWidth',4)
xlabel('Time [s]', 'FontSize', 20)















    
