% Code to make figure 2b : influence of the go command

clear all;

%CONTROL COMMANDS

% target of the movement
TARGET = 2;

%VARIABLES: INITIAL CONDITIONS

h_d(1)=0;
x_d(1)=0;
y_d(1)=0;

h_d2(1)=0;
x_d2(1)=0;
y_d2(1)=0;

%PARAMETERS

%discrete system
b = 10;

% EQ + INTEGRATION

%integration
dt   = 0.001; %time step 
T(1) = 0;


for i = [1:(3/dt)]

    g(i)=0; %initial goal
    h_d2(i)=0; %step like function
    
    
    % we change the goal and set the step-like function to 1
    if(i>500)
        g(i)=TARGET;
        h_d2(i)=1;
    end

    % everytime the goal is changed, the go command (presented in the paper) is reset to zero
    if(i>2)
        if(g(i)>(g(i-1)+0.1) || g(i)<(g(i-1)-0.1))
            h_d(i)=0;
        end
    end
 

    
    %DISCRETE SYSTEM
    dh_d(i) = 1-h_d(i);
    dx_d(i) = y_d(i);
    dy_d(i) = h_d(i)*b * (h_d(i)*b/4 *(g(i)-x_d(i)) - y_d(i));
    
    dx_d2(i) = y_d2(i);
    dy_d2(i) = h_d2(i)*b * (h_d2(i)*b/4 *(g(i)-x_d2(i)) - y_d2(i));


    %*******EULER**************

    T(i+1)=T(i)+dt;

    %discrete
    h_d(i+1)=h_d(i)+dh_d(i)*dt;
    y_d(i+1)=y_d(i)+dy_d(i)*dt;
    x_d(i+1)=x_d(i)+dx_d(i)*dt;
    
    y_d2(i+1)=y_d2(i)+dy_d2(i)*dt;
    x_d2(i+1)=x_d2(i)+dx_d2(i)*dt;

end


h_d2(i+1)=h_d2(i);
g(i+1)=g(i);

figure;

subplot(2,1,1)
plot(T, h_d2,'black', T, h_d,'red--', 'LineWidth',4)
xlabel('Time [s]', 'FontSize', 20)
ylabel('Activation','FontSize',20)
lim = get(gca,'YLim');
axis manual;
set(gca, 'YLim',[lim(1)-0.5 lim(2)+0.5],'FontSize',20);
set(gca,'YTick',[0 1]);

subplot(2,1,2)
plot( T, y_d2,'black', T, y_d,'red--', 'LineWidth',2)
hold on
plot(T,x_d2, 'black', T, x_d, 'red--', 'LineWidth',4)
xlabel('Time [s]', 'FontSize', 20)
ylabel('Pos/Vel','FontSize',20)
lim = get(gca,'YLim');
axis manual;
set(gca, 'YLim',[lim(1)-0.5 lim(2)+0.5],'FontSize',20);










    
