% Code to make figure 3a : different initial conditions

clear all;

%CONTROL COMMANDS

MU = 2;
OMEGA = 2*pi;

%PARAMETERS
%oscillators
a = 5;
c = 20;

%VARIABLES: INITIAL CONDITIONS
m(1)=0;
x_h(1)=-2;
v_h(1)=0;

m2(1)=0.5;
x_h2(1)=0;
v_h2(1)=0;

m3(1)=0;
x_h3(1)=2;
v_h3(1)=2;

% EQ + integration

%integration
dt   = 0.001;
T(1) = 0;
time=2;


for i = [1:(time/dt)]

    mu(i)=MU;
    mu2(i)=MU;
    mu3(i)=MU;
    
    omega(i)=OMEGA;
    omega2(i)=OMEGA;
    omega3(i)=OMEGA;
    
    %EQ
    
    r_h = sqrt(x_h(i)^2 + v_h(i)^2);
    dm(i) = c *(mu(i) -m(i)); 
    dx_h(i) = a/abs(mu(i)) * (m(i)-r_h^2) * x_h(i) - omega(i) * v_h(i)+randn;
    dv_h(i) = a/abs(mu(i)) * (m(i)-r_h^2) * v_h(i) + omega(i)* x_h(i)+randn;
    
    r_h2 = sqrt(x_h2(i)^2 + v_h2(i)^2);
    dm2(i) = c *(mu2(i) -m2(i)); 
    dx_h2(i) = a/abs(mu2(i)) * (m2(i)-r_h2^2) * x_h2(i) - omega2(i) * v_h2(i)+randn;
    dv_h2(i) = a/abs(mu2(i)) * (m2(i)-r_h2^2) * v_h2(i) + omega2(i)* x_h2(i)+randn ;

    r_h3 = sqrt(x_h3(i)^2 + v_h3(i)^2);
    dm3(i) = c *(mu3(i) -m3(i)); 
    dx_h3(i) = a/abs(mu3(i)) * (m3(i)-r_h3^2) * x_h3(i) - omega3(i) * v_h3(i)+randn;
    dv_h3(i) = a/abs(mu3(i)) * (m3(i)-r_h3^2) * v_h3(i) + omega3(i)* x_h3(i)+randn;

    %*******EULER**************

    T(i+1)=T(i)+dt;

    m(i+1)=m(i)+dm(i)*dt;
    x_h(i+1)=x_h(i)+dx_h(i)*dt;
    v_h(i+1)=v_h(i)+dv_h(i)*dt;
    
    m2(i+1)=m2(i)+dm2(i)*dt;
    x_h2(i+1)=x_h2(i)+dx_h2(i)*dt;
    v_h2(i+1)=v_h2(i)+dv_h2(i)*dt;
    
    m3(i+1)=m3(i)+dm3(i)*dt;
    x_h3(i+1)=x_h3(i)+dx_h3(i)*dt;
    v_h3(i+1)=v_h3(i)+dv_h3(i)*dt;


end

figure
subplot(2,1,1)
plot(T,x_h, 'blue-.', T, x_h2,'black',  T, x_h3,'red--','LineWidth',4)
xlabel('Time [s]', 'FontSize', 20)
ylabel('Position','FontSize',20)
lim = get(gca,'YLim');
axis manual;
set(gca, 'XLim', [0 time],'YLim',[lim(1)-0.5 lim(2)+0.5],'FontSize',20);

subplot(2,1,2)
plot(x_h,v_h, 'blue-.', x_h2, v_h2,'black', x_h3, v_h3,'red--','LineWidth',4)
xlabel('x', 'FontSize', 20)
ylabel('z','FontSize',20)
lim = get(gca,'YLim');
lim2 =get(gca,'Xlim');
axis manual;
set(gca, 'XLim', [lim(1)-0.5 lim(2)+0.5],'YLim',[lim(1)-0.5 lim(2)+0.5],'FontSize',20);






