% Code to make figure 3b : resistance to perturbations

clear all;

%CONTROL COMMANDS

MU = 1;
OMEGA =2*pi;

%PARAMETERS

%oscillators
a = 5;
c = 20;


%VARIABLES: INITIAL CONDITIONS

%we don't start at (0,0) as the convergence would be slower 

m(1)=0;
x_h(1)=1;
v_h(1)=0;

m2(1)=0;
x_h2(1)=1;
v_h2(1)=0;

m3(1)=0;
x_h3(1)=1;
v_h3(1)=0;

% EQ + integration

%integration
dt   = 0.001; %time step 
T(1) = 0;
time=8; %total time



for i = [1:(time/dt)]

    mu(i)=MU;
    mu2(i)=MU;
    omega2(i)=OMEGA;
    omega(i)=OMEGA;
        
    %cartesian rhythmic
    r_h = sqrt(x_h(i)^2 + v_h(i)^2);
    dm(i)=c*(mu(i)-m(i));
    dx_h(i) = a/abs(mu(i)) * (m(i)-r_h^2) * x_h(i) - omega(i) * v_h(i)+randn;
    dv_h(i) = a/abs(mu(i)) * (m(i)-r_h^2) * v_h(i) + omega(i)* x_h(i)+randn;
    
    r_h2 = sqrt(x_h2(i)^2 + v_h2(i)^2);        
    dm2(i)=c*(mu2(i)-m2(i)); 
    dx_h2(i) = a/abs(mu2(i)) * (m2(i)-r_h2^2) * x_h2(i) - omega2(i) * v_h2(i)+randn;
    dv_h2(i) = a/abs(mu2(i) )* (m2(i)-r_h2^2) * v_h2(i) + omega2(i)* x_h2(i)+randn;
    
    %perturbations
    
    if(i>1000 && i<2500)
        dx_h2(i)=0.5;
    end
    if(i>5000 && i<6000)
        dx_h2(i)=0;
    end

    
    
    %*******EULER**************

    T(i+1)=T(i)+dt;

    x_h(i+1)=x_h(i)+dx_h(i)*dt;
    v_h(i+1)=v_h(i)+dv_h(i)*dt;
    m(i+1) = m(i) + dm(i)*dt;
    
    x_h2(i+1)=x_h2(i)+dx_h2(i)*dt;
    v_h2(i+1)=v_h2(i)+dv_h2(i)*dt;
    m2(i+1) = m2(i) + dm2(i)*dt;


end

figure

subplot(2,1,1)
plot(T, x_h,'black--',  T, x_h2,'red', 'LineWidth',4)
xlabel('Time [s]', 'FontSize', 20)
ylabel('Pos/Vel','FontSize',20) 
lim = get(gca,'YLim');
axis manual;
set(gca, 'XLim', [0 time],'YLim',[lim(1)-0.5 lim(2)+0.5],'FontSize',20);
line([1 1],[lim(1)-0.5 lim(2)+0.5], 'color', 'black', 'linewidth', 2);
line([2.5 2.5],[lim(1)-0.5 lim(2)+0.5], 'color', 'black', 'linewidth', 2);
line([5 5],[lim(1)-0.5 lim(2)+0.5], 'color', 'black', 'linewidth', 2);
line([6 6],[lim(1)-0.5 lim(2)+0.5], 'color', 'black', 'linewidth', 2);

subplot(2,1,2)
plot( x_h2, v_h2, 'red',x_h, v_h, 'black--', 'LineWidth',4)
xlabel('x', 'FontSize', 20)
ylabel('z','FontSize',20)







