
% Code to make figure 3d : Modulation of frequency and entrainment

clear all;

%integration
dt   = 0.001; %time step
T(1) = 0;
time = 10; %total time


%CONTROL COMMANDS

for i=[1:(time/dt+1)]
    mu(i)=1;
    mu2(i)=1;
    mu3(i)=1;
    omega(i)=2*pi;
    omega2(i)=2*pi;
    omega3(i)=2*pi;
end
for i=[2000:4000]
    omega(i)=3*pi;
end
for i=[4000:6000]
    omega(i)=2*pi;
end
for i=[6000:8000]
    omega(i)=pi;
end

%PARAMETRES

%oscillators
a = 5;
c = 5;

%VARIABLES: INITIAL CONDITIONS

%we don't start at (0,0) as the convergence would be slower 

m(1)=0;
x_h(1)=1;
v_h(1)=0;

m2(1)=0;
x_h2(1)=1;
v_h2(1)=0;

m3(1)=0;
x_h3(1)=1;
v_h3(1)=0;



for i = [1:(time/dt)]

    
    %cartesian rhythmic
    r_h = sqrt(x_h(i)^2 + v_h(i)^2);
    dm(i)=c*(mu(i)-m(i));  
    dx_h(i) = a/abs(mu(i)) * (m(i)-r_h^2) * x_h(i) - omega(i) * v_h(i)+randn;
    dv_h(i) = a/abs(mu(i)) * (m(i)-r_h^2) * v_h(i) + omega(i)* x_h(i)+randn;
    
    r_h2 = sqrt(x_h2(i)^2 + v_h2(i)^2);
    dm2(i)=c*(mu2(i)-m2(i));  
    dx_h2(i) = a/abs(mu2(i)) * (m2(i)-r_h2^2) * x_h2(i) - omega2(i) * v_h2(i)+randn;
    dv_h2(i) = a/abs(mu2(i)) * (m2(i)-r_h2^2) * v_h2(i) + omega2(i)* x_h2(i)+randn;
    
    F(i)=0;
    if(i>2500)
        F(i)=sin(4*pi*i*dt);
    end
    if(i>8000)
        F(i)=0;
    end
    
    
    r_h3 = sqrt(x_h3(i)^2 + v_h3(i)^2);
    dm3(i)=c*(mu3(i)-m3(i));  
    dx_h3(i) = a * (m2(i)-r_h3^2) * x_h3(i) - omega3(i) * v_h3(i)+randn +10* F(i);
    dv_h3(i) = a * (m2(i)-r_h3^2) * v_h3(i) + omega3(i)* x_h3(i)+randn;% +10*F(i);

    
    
    %*******EULER**************

    T(i+1)=T(i)+dt;

    x_h(i+1)=x_h(i)+dx_h(i)*dt;
    v_h(i+1)=v_h(i)+dv_h(i)*dt;
    m(i+1) = m(i) + dm(i)*dt;
    
    x_h2(i+1)=x_h2(i)+dx_h2(i)*dt;
    v_h2(i+1)=v_h2(i)+dv_h2(i)*dt;
    m2(i+1) = m2(i) + dm2(i)*dt;
    
    x_h3(i+1)=x_h3(i)+dx_h3(i)*dt;
    v_h3(i+1)=v_h3(i)+dv_h3(i)*dt;
    m3(i+1) = m3(i) + dm3(i)*dt;
    
end

F(i+1)=0;


figure
subplot(2,1,1)
plot(T,x_h, 'red' ,'LineWidth',4)
xlabel('Time [s]', 'FontSize', 20)
ylabel('Position','FontSize',20)
lim = get(gca,'YLim');
axis manual;
set(gca, 'XLim', [0 time],'YLim',[lim(1)-0.5 lim(2)+0.5],'FontSize',20);
line([2 2],[lim(1)-0.5 lim(2)+0.5], 'color', 'black', 'linewidth', 2);
line([4 4],[lim(1)-0.5 lim(2)+0.5], 'color', 'black', 'linewidth', 2);
line([6 6],[lim(1)-0.5 lim(2)+0.5], 'color', 'black', 'linewidth', 2);
line([8 8],[lim(1)-0.5 lim(2)+0.5], 'color', 'black', 'linewidth', 2);

% 
subplot(2,1,2)
plot(T, F, 'black--', 'LineWidth',3)
hold on
plot(T, x_h3, 'red', 'LineWidth',4)
xlabel('Time [s]', 'FontSize', 20)
ylabel('Position','FontSize',20)
lim = get(gca,'YLim');
lim2 =get(gca,'Xlim');
axis manual;
set(gca, 'XLim', [0 time],'YLim',[lim(1)-0.5 lim(2)+0.5],'FontSize',20);







